@@ -436,11 +436,11 @@ def density(gf_iw, potential, beta, return_err=True, matrix=False, total=False):
         assert gf_iw.ndim == 1
 
     if matrix:
-        dec = gtmatrix.decompose_hamiltonian(potential)
-        xi = dec.xi
-        tail = dec.reconstruct(1./np.add.outer(iw, xi), kind='diag')
+        dec = gtmatrix.decompose_her(potential)
+        eig = dec.eig
+        tail = dec.reconstruct(1./np.add.outer(iw, eig), kind='diag')
         tail = np.moveaxis(tail, source=0, destination=-1)
-        analytic = dec.reconstruct(fermi_fct(-xi, beta=beta), kind='diag')
+        analytic = dec.reconstruct(fermi_fct(-eig, beta=beta), kind='diag')
     else:
         tail = 1/np.add.outer(potential, iw)
         analytic = fermi_fct(-potential, beta=beta)
@@ -565,8 +565,8 @@ def check_convergence(gf_iw, potential, beta, order=2, matrix=False, total=False
     iw = matsubara_frequencies(np.arange(gf_iw.shape[-1]), beta=beta)
 
     if matrix:
-        dec = gtmatrix.decompose_hamiltonian(potential)
-        tail = dec.reconstruct(1./np.add.outer(dec.xi, iw), kind='diag')
+        dec = gtmatrix.decompose_her(potential)
+        tail = dec.reconstruct(1./np.add.outer(dec.eig, iw), kind='diag')
     else:
         tail = 1/np.add.outer(potential, iw)
 
