@@ -369,6 +369,7 @@ def gf_tau(tau, poles, weights, beta):
 
 
 def _single_pole_gf_ret_t(tt, pole):
+    """Retarded time Green's function for a single `pole`."""
     return np.where(tt >= 0, -1j*np.exp(-1j*pole*tt, where=(tt >= 0)), 0)
 
 
@@ -397,6 +398,16 @@ def gf_ret_t(tt, poles, weights):
     return _gu_sum(weights*_single_pole_gf_ret_t(tt[..., newaxis], pole=poles))
 
 
+def _single_pole_gf_gr_t(tt, pole, beta):
+    """Greater time Green's function for a single `pole`."""
+    return -1j * np.exp(-1j*pole*tt) * (1 - fermi_fct(pole, beta))
+
+
+def _single_pole_gf_le_t(tt, pole, beta):
+    """Lesser time Green's function for a single `pole`."""
+    return 1j * np.exp(-1j*pole*tt) * fermi_fct(pole, beta)
+
+
 def moments(poles, weights, order):
     r"""High-frequency moments of the pole Green's function.
 
