@@ -28,7 +28,7 @@ with the hybridization function
 import numpy as np
 
 from gftool._util import _gu_sum
-from gftool.matrix import decompose_hamiltonian
+from gftool.matrix import decompose_her
 from gftool.basis.pole import (_single_pole_gf_gr_t, _single_pole_gf_le_t,
                                _single_pole_gf_ret_t)
 
@@ -77,11 +77,11 @@ def gf0_loc_ret_t(tt, e_onsite, e_bath, hopping):
 
     """
     ham = hamiltonian_matrix(e_onsite, e_bath=e_bath, hopping=hopping)
-    dec = decompose_hamiltonian(ham)
+    dec = decompose_her(ham)
     # calculate only elements [..., 0] corresponding to the local impurity site
     dec.rv_inv, dec.rv = dec.rv_inv[..., :, :1], dec.rv[..., :1, :]
-    eig_exp = _single_pole_gf_ret_t(tt[..., np.newaxis], dec.xi)
-    gf0_t = dec.reconstruct(xi=eig_exp, kind='diag')[..., 0]
+    eig_exp = _single_pole_gf_ret_t(tt[..., np.newaxis], dec.eig)
+    gf0_t = dec.reconstruct(eig=eig_exp, kind='diag')[..., 0]
     return gf0_t
 
 
@@ -108,11 +108,11 @@ def gf0_loc_gr_t(tt, e_onsite, e_bath, hopping, beta):
 
     """
     ham = hamiltonian_matrix(e_onsite, e_bath=e_bath, hopping=hopping)
-    dec = decompose_hamiltonian(ham)
+    dec = decompose_her(ham)
     # calculate only elements [..., 0] corresponding to the local impurity site
     dec.rv_inv, dec.rv = dec.rv_inv[..., :, :1], dec.rv[..., :1, :]
-    eig_exp = _single_pole_gf_gr_t(tt[..., np.newaxis], dec.xi, beta=beta)
-    gf0_t = dec.reconstruct(xi=eig_exp, kind='diag')[..., 0]
+    eig_exp = _single_pole_gf_gr_t(tt[..., np.newaxis], dec.eig, beta=beta)
+    gf0_t = dec.reconstruct(eig=eig_exp, kind='diag')[..., 0]
     return gf0_t
 
 
@@ -139,11 +139,11 @@ def gf0_loc_le_t(tt, e_onsite, e_bath, hopping, beta):
 
     """
     ham = hamiltonian_matrix(e_onsite, e_bath=e_bath, hopping=hopping)
-    dec = decompose_hamiltonian(ham)
+    dec = decompose_her(ham)
     # calculate only elements [..., 0] corresponding to the local impurity site
     dec.rv_inv, dec.rv = dec.rv_inv[..., :, :1], dec.rv[..., :1, :]
-    eig_exp = _single_pole_gf_le_t(tt[..., np.newaxis], dec.xi, beta=beta)
-    gf0_t = dec.reconstruct(xi=eig_exp, kind='diag')[..., 0]
+    eig_exp = _single_pole_gf_le_t(tt[..., np.newaxis], dec.eig, beta=beta)
+    gf0_t = dec.reconstruct(eig=eig_exp, kind='diag')[..., 0]
     return gf0_t
 
 
@@ -165,8 +165,6 @@ def hamiltonian_matrix(e_onsite, e_bath, hopping):
         On-site energy of the bath sites.
     hopping : (..., Nb) complex np.ndarray
         Hopping matrix element between impurity and the bath sites.
-    beta : float
-        The inverse temperature :math:`beta = 1/k_B T`.
 
     Returns
     -------
