@@ -4,6 +4,7 @@ from __future__ import absolute_import
 import os
 
 from sys import path
+from functools import lru_cache
 
 PATH = os.path.abspath(os.path.dirname(__file__))
 path.insert(0, os.path.join(PATH, os.pardir, os.pardir))
@@ -18,3 +19,6 @@ import gftool.linalg
 import gftool.basis.pole as pole
 import gftool.siam
 import gftool._util
+
+
+gftool.statistics._pade_frequencies = lru_cache(maxsize=10)(gftool.statistics._pade_frequencies)
